@@ -60,18 +60,21 @@ void set_colorpairs(void)
 		colortype *combo = color_combo[i];
 
 		if (combo != NULL) {
-			if (combo->fg == -1 && !using_defaults)
+			if (combo->fg == USE_THE_DEFAULT && !using_defaults)
 				combo->fg = COLOR_WHITE;
-			if (combo->bg == -1 && !using_defaults)
+			if (combo->bg == USE_THE_DEFAULT && !using_defaults)
 				combo->bg = COLOR_BLACK;
 			init_pair(i + 1, combo->fg, combo->bg);
 			interface_color_pair[i] = COLOR_PAIR(i + 1) | A_BANDAID |
 										(combo->bright ? A_BOLD : A_NORMAL);
 		} else {
-			if (i != FUNCTION_TAG)
-				interface_color_pair[i] = hilite_attribute;
-			else
+			if (i == FUNCTION_TAG)
 				interface_color_pair[i] = A_NORMAL;
+			else if (i == ERROR_MESSAGE) {
+				init_pair(i + 1, COLOR_WHITE, COLOR_RED);
+				interface_color_pair[i] = COLOR_PAIR(i + 1) | A_BOLD | A_BANDAID;
+			} else
+				interface_color_pair[i] = hilite_attribute;
 		}
 
 		free(color_combo[i]);
@@ -87,8 +90,7 @@ void set_colorpairs(void)
 			const colortype *beforenow = sint->color;
 
 			while (beforenow != ink && (beforenow->fg != ink->fg ||
-										beforenow->bg != ink->bg ||
-										beforenow->bright != ink->bright))
+										beforenow->bg != ink->bg))
 				beforenow = beforenow->next;
 
 			if (beforenow != ink)
@@ -123,10 +125,10 @@ void color_init(void)
 		foreground = ink->fg;
 		background = ink->bg;
 
-		if (foreground == -1 && !using_defaults)
+		if (foreground == USE_THE_DEFAULT && !using_defaults)
 			foreground = COLOR_WHITE;
 
-		if (background == -1 && !using_defaults)
+		if (background == USE_THE_DEFAULT && !using_defaults)
 			background = COLOR_BLACK;
 
 		init_pair(ink->pairnum, foreground, background);
