@@ -543,7 +543,8 @@ enum
 	SHOW_CURSOR,
 	LINE_NUMBERS,
 	NO_PAUSES,
-	AT_BLANKS
+	AT_BLANKS,
+	AFTER_ENDS
 };
 
 /* Flags for the menus in which a given function should be present. */
